ISONAS Access Control System
============================

![alt tag](https://travis-ci.org/vbastos/isonasacs.svg?branch=master)

API to communicate with the Crystal Matrix Software of ISONAS. ISONAS provides pure IP access control solutions.